==> ganglia-monitor-core-3.0.1_2.tbz: etc/rc.d/ganglia.sh <==
#!/bin/sh
# $FreeBSD: ports/sysutils/ganglia-monitor-core/files/ganglia.sh.in,v 1.2 2005/04/27 17:52:41 brooks Exp $

# PROVIDE: ganglia
# REQIORE: DAEMON
# KEYWORD: FreeBSD shutdown

# XXX: This should really be two seperate scripts with rcorder
# dependencies, but we can't do that at the moment and gmetad doesn't
# work without a running gmond.

gmond_enable="NO"
gmond_conf="/usr/local/etc/gmond.conf"

gmetad_enable="NO"
gmetad_conf="/usr/local/etc/gmetad.conf"
gmetasnap_enable="NO"
gmetasnap_rrddir="/var/db/ganglia/rrds"
gmetasnap_snapdir="/var/db/ganglia/snaps"
gmetasnap_snapname="snap"
gmetasnap_flags=""
gmetasnap_command="/usr/local/sbin/gmetasnap"

### gmond ###

. /etc/rc.subr

name=gmond
rcvar=`set_rcvar`
command="/usr/local/sbin/${name}"

load_rc_config ganglia

load_rc_config $name
command_args="-c ${gmond_conf}"
required_files=${gmond_conf}

run_rc_command $*

### gmetad ###

# Don't continue if we didn't run gmond
if ! checkyesno ${rcvar}; then
	return 0
fi

name=gmetad
rcvar=`set_rcvar`
command="/usr/local/sbin/${name}"
start_precmd="gmetad_prestart"
stop_postcmd="gmetad_poststop"

gmetad_prestart()
{
	if [ ! -d ${gmetasnap_rrddir} ]; then
		mkdir -p ${gmetasnap_rrddir}
	fi
	chown ganglia:ganglia ${gmetasnap_rrddir}
	if checkyesno gmetasnap_enable; then
		if [ ! -d ${gmetasnap_snapdir} ]; then
			mkdir -p ${gmetasnap_snapdir}
			chown ganglia:ganglia ${gmetasnap_snapdir}
		fi
		if [ `ls ${gmetasnap_rrddir} | egrep -v ^.snap | wc -l` -eq 0 ]; then
			${gmetasnap_command} -r ${gmetasnap_rrddir} \
			    -s ${gmetasnap_snapdir} ${gmetasnap_flags} \
			    restore ${gmetasnap_snapname}
		fi
	fi
}

gmetad_poststop()
{
	if checkyesno gmetasnap_enable; then
		${gmetasnap_command} -r ${gmetasnap_rrddir} \
		    -s ${gmetasnap_snapdir} ${gmetasnap_flags} \
		    save ${gmetasnap_snapname}
	fi
}

load_rc_config $name
command_args="-c ${gmetad_conf}"
required_files=${gmetad_conf}

run_rc_command $*

==> ganglia-monitor-core-3.0.1_3.tbz: etc/rc.d/ganglia.sh <==
#!/bin/sh
# $FreeBSD: ports/sysutils/ganglia-monitor-core/files/ganglia.sh.in,v 1.4 2006/02/20 20:47:42 dougb Exp $

# PROVIDE: ganglia
# REQIORE: DAEMON
# KEYWORD: shutdown

# XXX: This should really be two seperate scripts with rcorder
# dependencies, but we can't do that at the moment and gmetad doesn't
# work without a running gmond.

gmond_enable="${gmond_enable-NO}"
gmond_conf="/usr/local/etc/gmond.conf"

gmetad_enable="${gmetad_enable-NO}"
gmetad_conf="/usr/local/etc/gmetad.conf"
gmetasnap_enable="${gmetasnap_enable-NO}"
gmetasnap_rrddir="/var/db/ganglia/rrds"
gmetasnap_snapdir="/var/db/ganglia/snaps"
gmetasnap_snapname="snap"
gmetasnap_flags=""
gmetasnap_command="/usr/local/sbin/gmetasnap"

### gmond ###

. /etc/rc.subr

name=gmond
rcvar=`set_rcvar`
command="/usr/local/sbin/${name}"

load_rc_config ganglia

load_rc_config $name
command_args="-c ${gmond_conf}"
required_files=${gmond_conf}

run_rc_command $*

### gmetad ###

# Don't continue if we didn't run gmond
if ! checkyesno ${rcvar}; then
	return 0
fi

name=gmetad
rcvar=`set_rcvar`
command="/usr/local/sbin/${name}"
start_precmd="gmetad_prestart"
stop_postcmd="gmetad_poststop"

gmetad_prestart()
{
	if [ ! -d ${gmetasnap_rrddir} ]; then
		mkdir -p ${gmetasnap_rrddir}
	fi
	chown ganglia:ganglia ${gmetasnap_rrddir}
	if checkyesno gmetasnap_enable; then
		if [ ! -d ${gmetasnap_snapdir} ]; then
			mkdir -p ${gmetasnap_snapdir}
			chown ganglia:ganglia ${gmetasnap_snapdir}
		fi
		if [ `ls ${gmetasnap_rrddir} | egrep -v ^.snap | wc -l` -eq 0 ]; then
			${gmetasnap_command} -r ${gmetasnap_rrddir} \
			    -s ${gmetasnap_snapdir} ${gmetasnap_flags} \
			    restore ${gmetasnap_snapname}
		fi
	fi
}

gmetad_poststop()
{
	if checkyesno gmetasnap_enable; then
		${gmetasnap_command} -r ${gmetasnap_rrddir} \
		    -s ${gmetasnap_snapdir} ${gmetasnap_flags} \
		    save ${gmetasnap_snapname}
	fi
}

load_rc_config $name
command_args="-c ${gmetad_conf}"
required_files=${gmetad_conf}

run_rc_command $*
